---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legge:2025-03-28;36!vig=2025-11-04
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20250328&codiceRedaz=25G00049&dataVigenza=20251104
dataGU: 20250328
codiceRedaz: 25G00049
dataVigenza: 20251104
---

# Disposizioni urgenti in materia di cittadinanza. (25G00049)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 77 e 87, quinto comma, della Costituzione;

Vista la legge 23 agosto 1988, n. 400, recante «Disciplina dell'attivita' di Governo e ordinamento della Presidenza del Consiglio dei ministri» e, in particolare, l'articolo 15;

Visto il codice civile approvato con regio decreto 25 giugno 1865, n. 2358, e in particolare gli articoli da 4 a 15;

Vista la legge 13 giugno 1912, n. 555, recante disposizioni «Sulla cittadinanza italiana»;

Vista la legge 21 aprile 1983, n. 123, recante «Disposizioni in materia di cittadinanza»;

Vista la legge 5 febbraio 1992, n. 91, recante «Nuove norme sulla cittadinanza»;

Visto il decreto legislativo 1° settembre 2011, n. 150, recante «Disposizioni complementari al codice di procedura civile in materia di riduzione e semplificazione dei procedimenti civili di cognizione, ai sensi dell'articolo 54 della legge 18 giugno 2009, n. 69» e in particolare l'articolo 19-bis;

Ritenuta pertanto la straordinaria necessita' ed urgenza di introdurre limitazioni nella trasmissione automatica della cittadinanza italiana a persone nate e residenti all'estero, condizionandola a chiari indici della sussistenza di vincoli effettivi con la Repubblica;

Ritenuta pertanto la straordinaria necessita' ed urgenza di operare un bilanciamento tra i principi di cui agli articoli 1 e 3 della Costituzione, applicando le suddette limitazioni a tutti i futuri riconoscimenti di cittadinanza italiana ed evitando l'intrinseca irragionevolezza di riconoscimenti della cittadinanza italiana secondo criteri diversi a seconda di un fattore casuale e non indicativo di vincoli effettivi con la Repubblica, quale la nascita dei richiedenti, in luogo dell'effettivo esercizio di diritti o adempimento di doveri connessi con lo stato di cittadino;

Ritenuta la straordinaria necessita' e urgenza di introdurre misure per evitare, nelle more dell'approvazione di una riforma organica delle disposizioni in materia di cittadinanza, un eccezionale e incontrollato afflusso di domande di riconoscimento della cittadinanza, tale da impedire l'ordinata funzionalita' degli uffici consolari all'estero, dei comuni e degli uffici giudiziari;

Vista la deliberazione del Consiglio dei ministri, adottata nella riunione del 28 marzo 2025;

Sulla proposta del Presidente del Consiglio dei ministri e dei Ministri degli affari esteri e della cooperazione internazionale e dell'interno, di concerto con i Ministri della giustizia e dell'economia e delle finanze;

Emana il seguente decreto-legge:

## Art. 1. - Disposizioni urgenti in materia di cittadinanza

1. Alla legge 5 febbraio 1992, n. 91, dopo l'articolo 3 e' inserito il seguente: «Art. 3-bis. - 1. In deroga agli articoli 1, 2, 3, 14 e 20 della presente legge, all'articolo 5 della legge 21 aprile 1983, n. 123, agli articoli 1, 2, 7, 10, 12 e 19 della legge 13 giugno 1912, n. 555, nonche' agli articoli 4, 5, 7, 8 e 9 del codice civile approvato con regio decreto 25 giugno 1865, n. 2358, e' considerato non avere mai acquistato la cittadinanza italiana chi e' nato all'estero anche prima della data di entrata in vigore del presente articolo ed e' in possesso di altra cittadinanza, salvo che ricorra una delle seguenti condizioni: a) lo stato di cittadino dell'interessato e' riconosciuto, nel rispetto della normativa applicabile al 27 marzo 2025, a seguito di domanda, corredata della necessaria documentazione, presentata all'ufficio consolare o al sindaco competenti non oltre le 23:59, ora di Roma, della medesima data; a-bis) ((lo stato di cittadino dell'interessato e' riconosciuto, nel rispetto della normativa applicabile al 27 marzo 2025, a seguito di domanda, corredata della necessaria documentazione, presentata all'ufficio consolare o al sindaco competenti nel giorno indicato da appuntamento comunicato all'interessato dall'ufficio competente entro le 23:59, ora di Roma, della medesima data del 27 marzo 2025)); b) lo stato di cittadino dell'interessato e' accertato giudizialmente, nel rispetto della normativa applicabile al 27 marzo 2025, a seguito di domanda giudiziale presentata non oltre le 23:59, ora di Roma, della medesima data; c) ((un ascendente di primo o di secondo grado possiede, o possedeva al momento della morte, esclusivamente la cittadinanza italiana)); d) ((un genitore o adottante e' stato residente in Italia per almeno due anni continuativi successivamente all'acquisto della cittadinanza italiana e prima della data di nascita o di adozione del figlio)); e) ((LETTERA SOPPRESSA DALLA L. 23 MAGGIO 2025, N. 74)). 1-bis. ((All'articolo 4 della legge 5 febbraio 1992, n. 91, sono apportate le seguenti modificazioni: a) al comma 1, alinea, dopo le parole: "secondo grado" sono inserite le seguenti: "sono o"; b) dopo il comma 1 sono inseriti i seguenti: "1-bis. Il minore straniero o apolide, del quale il padre o la madre sono cittadini per nascita, diviene cittadino se i genitori o il tutore dichiarano la volonta' dell'acquisto della cittadinanza e ricorre uno dei seguenti requisiti: a) successivamente alla dichiarazione, il minore risiede legalmente per almeno due anni continuativi in Italia; b) la dichiarazione e' presentata entro un anno dalla nascita del minore o dalla data successiva in cui e' stabilita la filiazione, anche adottiva, da cittadino italiano. 1-ter. Divenuto maggiorenne, chi ha acquistato la cittadinanza ai sensi del comma 1-bis puo' rinunciarvi se in possesso di altra cittadinanza")). 1-ter. ((Per i minorenni alla data di entrata in vigore della legge di conversione del presente decreto, figli di cittadini per nascita di cui all'articolo 3-bis, comma 1, lettere a), a-bis) e b), della legge 5 febbraio 1992, n. 91, la dichiarazione prevista dall'articolo 4, comma 1-bis, lettera b), della medesima legge puo' essere presentata entro le 23:59, ora di Roma, del 31 maggio 2026.)) 1-quater. ((All'articolo 14, comma 1, della legge 5 febbraio 1992, n. 91, e' aggiunto, in fine, il seguente periodo: "Il primo periodo si applica se, alla data di acquisto o riacquisto della cittadinanza da parte del genitore, il minore risiede legalmente in Italia da almeno due anni continuativi o, se di eta' inferiore ai due anni, dalla nascita")). 2. All'articolo 19-bis del decreto legislativo 1° settembre 2011, n. 150, sono apportate le seguenti modificazioni: a) la rubrica e' sostituita dalla seguente: «Controversie in materia di accertamento dello stato di apolidia e di cittadinanza italiana»; b) dopo il comma 2 sono aggiunti i seguenti: «2-bis. Salvi i casi espressamente previsti dalla legge, nelle controversie in materia di accertamento della cittadinanza italiana non sono ammessi il giuramento e la prova testimoniale. 2-ter. Nelle controversie in materia di accertamento della cittadinanza italiana chi chiede l'accertamento della cittadinanza e' tenuto ad allegare e provare l'insussistenza delle cause di mancato acquisto o di perdita della cittadinanza previste dalla legge.».

## Art. 1-bis. - (( (Disposizioni per favorire il recupero delle radici italiane degli oriundi e il conseguente acquisto della cittadinanza italiana).))

1. ((All'articolo 27 del testo unico delle disposizioni concernenti la disciplina dell'immigrazione e norme sulla condizione dello straniero, di cui al decreto legislativo 25 luglio 1998, n. 286, dopo il comma 1-septies e' inserito il seguente: "1-octies. Sono consentiti, al di fuori delle quote di cui all'articolo 3, comma 4, con le procedure di cui all'articolo 22, l'ingresso e il soggiorno per lavoro subordinato allo straniero residente all'estero, discendente di cittadino italiano e in possesso della cittadinanza di uno Stato di destinazione di rilevanti flussi di emigrazione italiana, individuato con decreto del Ministro degli affari esteri e della cooperazione internazionale, di concerto con i Ministri dell'interno e del lavoro e delle politiche sociali".))

2. ((All'articolo 9, comma 1, della legge 5 febbraio 1992, n. 91, sono apportate le seguenti modificazioni: a) alla lettera a), dopo le parole: "secondo grado" sono inserite le seguenti: "sono o" e le parole: ", o che e' nato nel territorio della Repubblica e, in entrambi i casi, vi risiede legalmente da almeno tre anni" sono sostituite dalle seguenti: "e che risiede legalmente nel territorio della Repubblica da almeno due anni"; b) dopo la lettera a) e' inserita la seguente: "a-bis) allo straniero nato nel territorio della Repubblica che vi risiede legalmente da almeno tre anni".))

## Art. 1-ter. - (( (Riacquisto della cittadinanza a favore di ex cittadini).))

1. ((Alla legge 5 febbraio 1992, n. 91, sono apportate le seguenti modificazioni: a) all'articolo 9-bis, comma 2, dopo la parola: "cittadinanza" sono inserite le seguenti: ", ad eccezione delle dichiarazioni di riacquisto presentate innanzi a un ufficio consolare,"; b) all'articolo 17, il comma 1 e' sostituito dal seguente: "1. Fermo restando quanto previsto dall'articolo 3-bis, chi e' nato in Italia o e' stato ivi residente per almeno due anni continuativi e ha perduto la cittadinanza in applicazione dell'articolo 8, numeri 1 e 2, o dell'articolo 12 della legge 13 giugno 1912, n. 555, la riacquista se effettua una dichiarazione in tal senso in data compresa tra il 1° luglio 2025 e il 31 dicembre 2027".))

2. ((Alla sezione I della tabella dei diritti consolari da riscuotersi dagli uffici diplomatici e consolari, allegata al decreto legislativo 3 febbraio 2011, n. 71, dopo l'articolo 7-bis e' inserito il seguente: "Art. 7-ter. - Dichiarazione di riacquisto della cittadinanza: euro 250")).

## Art. 2. - Entrata in vigore

1. Il presente decreto entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale della Repubblica italiana e sara' presentato alle Camere per la conversione in legge.

